interest

# XMLRésuméLibrary: User Guide

institution | Element Reference | interests

## Name

interest — Something a person is interested in

## Synopsis

### Content Model

    (title,description?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `interest` element describes something that a person is interested in. A common use for `interest` elements is to list hobbies.

### Formatting

The formatting of `interest` is more complex than that of many other elements. The title is always displayed first, in standard font. Then, if there is a description, and the `interest.description.format` parameter value is `single-line`, a period and a space (“. ”) are displayed. Finally, the description is output, formatted according to the `interest.description.format` parameter.

### Parents

`interest` may be contained in these elements: `interests`

## See Also

`skill`.

## Examples

    <interest>
      <title>Sewing</title>
    </interest>

    <interest>
      <title>Seattle Mariners</title>
      <description>
        <para>I'm a season ticket holder.</para>
        <para><emphasis>GO MARINERS!</emphasis></para>
      </description>
    </interest>

For additional examples, see `interests`.

institution | Element Reference | interests